@@ -1,8 +1,16 @@
 """aio.core.directory."""
 
 from .context import ADirectoryContext, IDirectoryContext
-from .abstract import ADirectory, ADirectoryFileFinder, AGitDirectory
-from .directory import Directory, DirectoryFileFinder, GitDirectory
+from .abstract import (
+    ADirectory,
+    ADirectoryFileFinder,
+    AGitDirectory,
+    AGitDirectoryFileFinder)
+from .directory import (
+    Directory,
+    DirectoryFileFinder,
+    GitDirectory,
+    GitDirectoryFileFinder)
 from . import utils
 
 
@@ -11,8 +19,10 @@ __all__ = (
     "ADirectoryContext",
     "ADirectoryFileFinder",
     "AGitDirectory",
+    "AGitDirectoryFileFinder",
     "Directory",
     "DirectoryFileFinder",
     "GitDirectory",
+    "GitDirectoryFileFinder",
     "IDirectoryContext",
     "utils")
